[Qa-jenkins-scm] [jenkins.debian.net] 01/01: reproducible debian: bump daily scheduling limit to 500 for lamby

Holger Levsen holger at layer-acht.org
Fri Sep 23 21:11:18 UTC 2016


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit b2b801b5c5a0b372196735146b9db12988b3c532
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Sep 23 23:11:02 2016 +0200

    reproducible debian: bump daily scheduling limit to 500 for lamby
---
 bin/reproducible_remote_scheduler.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/bin/reproducible_remote_scheduler.py b/bin/reproducible_remote_scheduler.py
index 6ba1f3a..26fc79d 100755
--- a/bin/reproducible_remote_scheduler.py
+++ b/bin/reproducible_remote_scheduler.py
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
 log.debug('date_scheduled = ' + date + ' time_delta = ' + str(time_delta))
 
 
 # a single person can't schedule more than 200 packages in the same day; this
 # is actually easy to bypass, but let's give some trust to the Debian people
 query = '''SELECT count(*) FROM manual_scheduler
            WHERE requester = "{}" AND date_request > "{}"'''
@@ -221,7 +221,7 @@ try:
 except IndexError:
     amount = 0
 log.debug(requester + ' already scheduled ' + str(amount) + ' packages today')
-if amount + len(ids) > 200 and not local:
+if amount + len(ids) > 500 and not local:
     log.error(bcolors.FAIL + 'You have exceeded the maximum number of manual ' +
               'reschedulings allowed for a day. Please ask in ' +
               '#debian-reproducible if you need to schedule more packages.' +
@@ -212,7 +212,7 @@ date = (now - time_delta).strftime('%Y-%m-%d %H:%M')
 
 
-# a single person can't schedule more than 200 packages in the same day; this
+# a single person can't schedule more than 500 packages in the same day; this
 # is actually easy to bypass, but let's give some trust to the Debian people
 query = '''SELECT count(*) FROM manual_scheduler

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list